@@ -57,14 +57,13 @@ my %hierarchy = (
     'FormatScheme' => 'ResourceBase',
     'FractionElement' => 'MathElement',
     'FunctionElement' => 'MathElement',
-    'GifExportOptions' => 'ExportOptions',
     'GradientFill' => 'FillFormat',
     'GroupingCharacterElement' => 'MathElement',
     'HeaderFooter' => 'ResourceBase',
     'Html5ExportOptions' => 'ExportOptions',
     'HtmlExportOptions' => 'ExportOptions',
     'Image' => 'ResourceBase',
-    'ImageExportOptions' => 'ExportOptions',
+    'ImageExportOptionsBase' => 'ExportOptions',
     'Images' => 'ResourceBase',
     'LayoutSlide' => 'ResourceBase',
     'LayoutSlides' => 'ResourceBase',
@@ -130,7 +129,6 @@ my %hierarchy = (
     'TextElement' => 'MathElement',
     'TextItems' => 'ResourceBase',
     'Theme' => 'ResourceBase',
-    'TiffExportOptions' => 'ExportOptions',
     'UpdateBackground' => 'Task',
     'UpdateShape' => 'Task',
     'VideoExportOptions' => 'ExportOptions',
@@ -144,14 +142,17 @@ my %hierarchy = (
     'Chart' => 'ShapeBase',
     'DocumentReplaceResult' => 'Document',
     'GeometryShape' => 'ShapeBase',
+    'GifExportOptions' => 'ImageExportOptionsBase',
     'GraphicalObject' => 'ShapeBase',
     'GroupShape' => 'ShapeBase',
+    'ImageExportOptions' => 'ImageExportOptionsBase',
     'OleObjectFrame' => 'ShapeBase',
     'ScatterSeries' => 'XYSeries',
     'SlideReplaceResult' => 'Slide',
     'SmartArt' => 'ShapeBase',
     'SummaryZoomFrame' => 'ShapeBase',
     'Table' => 'ShapeBase',
+    'TiffExportOptions' => 'ImageExportOptionsBase',
     'WaterfallChartDataPoint' => 'OneValueChartDataPoint',
     'WaterfallSeries' => 'OneValueSeries',
     'ZoomObject' => 'ShapeBase',
@@ -168,6 +169,7 @@ my %hierarchy = (
 );
 
 my %determiners = (
+    'AccessPermissions' => {  },
     'ApiInfo' => {  },
     'ArrowHeadProperties' => {  },
     'Axes' => {  },
@@ -222,6 +224,7 @@ my %determiners = (
     'PathSegment' => {  },
     'Pipeline' => {  },
     'PlotArea' => {  },
+    'PortionFormat' => {  },
     'PresentationToMerge' => {  },
     'PresentationsMergeRequest' => {  },
     'PresetShadowEffect' => {  },
@@ -275,14 +278,13 @@ my %determiners = (
     'FormatScheme' => {  },
     'FractionElement' => { 'Type' => 'Fraction', },
     'FunctionElement' => { 'Type' => 'Function', },
-    'GifExportOptions' => { 'Format' => 'gif', },
     'GradientFill' => { 'Type' => 'Gradient', },
     'GroupingCharacterElement' => { 'Type' => 'GroupingCharacter', },
     'HeaderFooter' => {  },
     'Html5ExportOptions' => { 'Format' => 'html5', },
     'HtmlExportOptions' => { 'Format' => 'html', },
     'Image' => {  },
-    'ImageExportOptions' => { 'Format' => 'image', },
+    'ImageExportOptionsBase' => {  },
     'Images' => {  },
     'LayoutSlide' => {  },
     'LayoutSlides' => {  },
@@ -348,7 +350,6 @@ my %determiners = (
     'TextElement' => { 'Type' => 'Text', },
     'TextItems' => {  },
     'Theme' => {  },
-    'TiffExportOptions' => { 'Format' => 'tiff', },
     'UpdateBackground' => { 'Type' => 'UpdateBackground', },
     'UpdateShape' => { 'Type' => 'UpdateShape', },
     'VideoExportOptions' => { 'Format' => 'mpeg4', },
@@ -362,14 +363,17 @@ my %determiners = (
     'Chart' => { 'Type' => 'Chart', },
     'DocumentReplaceResult' => {  },
     'GeometryShape' => {  },
+    'GifExportOptions' => { 'Format' => 'gif', },
     'GraphicalObject' => { 'Type' => 'GraphicalObject', },
     'GroupShape' => { 'Type' => 'GroupShape', },
+    'ImageExportOptions' => { 'Format' => 'image', },
     'OleObjectFrame' => { 'Type' => 'OleObjectFrame', },
     'ScatterSeries' => { 'DataPointType' => 'Scatter', },
     'SlideReplaceResult' => {  },
     'SmartArt' => { 'Type' => 'SmartArt', },
     'SummaryZoomFrame' => { 'Type' => 'SummaryZoomFrame', },
     'Table' => { 'Type' => 'Table', },
+    'TiffExportOptions' => { 'Format' => 'tiff', },
     'WaterfallChartDataPoint' => {  },
     'WaterfallSeries' => { 'DataPointType' => 'OneValue', },
     'ZoomObject' => {  },
